# pynspector
The `human-friendly` python objects inspector

### What is pynspector?
Pynspector is a library for easily inspecting python objects. It wraps the "inspect" library and adds some extra
features to make it more powerful and easy to use.

I've been playing with `inspect` library some time, and after cracking my brain I just decided to start this new project.

But that's not the only thing it does by default (wrapping the `inspect` library) it also adds support for being able
to parse docstrings and return all specifications defined for a function.